package com.css.simulation.resource.common.controller;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.MinioParameter;
import api.common.util.FileUtil;
import com.css.simulation.resource.common.util.MinioUtil;
import io.minio.MinioClient;
import io.minio.errors.*;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;

@RestController
@RequestMapping("/minio")
public class MinioController {

    @Resource
    private MinioClient minioClient;


    @RequestMapping("/hello")
    public String hello() {
        return "hello minio!";
    }

    @RequestMapping("/upload")
    public ResponseBodyVO<String> upload(
            @RequestParam("file") MultipartFile multipartFile,
            @RequestParam("bucketName") String bucketName,
            @RequestParam("objectName") String objectName
    ) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {
        MinioUtil.uploadFromMultipartFile(
                minioClient,
                multipartFile,
                bucketName,
                objectName
        );
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS);
    }

    @RequestMapping("/download")
    public ResponseBodyVO<String> download(
            @RequestBody @Validated MinioParameter minioParameter,
            HttpServletResponse response
    ) throws ServerException, InsufficientDataException, ErrorResponseException, IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException, XmlParserException, InternalException {
        InputStream inputStream = MinioUtil.downloadToStream(
                minioClient,
                minioParameter.getBucketName(),
                minioParameter.getObjectName()
        );
        String fileName = FileUtil.getFileName(minioParameter.getObjectName());
        FileUtil.downloadForHttp(fileName, inputStream, response, 1024);
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS);
    }

}
