package com.css.simulation.resource.common.controller;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.RedisParameter;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.time.Duration;


/**
 * https://blog.csdn.net/lzb348110175/article/details/105349109/
 */
@RestController
@RequestMapping("/redis")
public class RedisController {

    @Resource
    RedisTemplate<String, String> redisTemplate;

    @RequestMapping("/get")
    public ResponseBodyVO<String> get(@RequestParam("key") String key) {
        //1 获取 key 对应的值
        String value = redisTemplate.opsForValue().get(key);

        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS,"请求成功！", value);
    }

    @RequestMapping("/set")
    public ResponseBodyVO<String> set(@RequestBody @Validated RedisParameter redisParameter) {
        //2 存储键值对并设置时间。
        redisTemplate.opsForValue().set(redisParameter.getKey(), redisParameter.getValue(), Duration.ofMinutes(30L));
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS);
    }

    @RequestMapping("/getExpire")
    public ResponseBodyVO<Long> getExpire(@RequestParam("key") String key) {
        //3 获取指定 key 的剩余时间，单位秒。
        Long time3 = redisTemplate.getExpire("key3");
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, time3);
    }


    @RequestMapping("/delete")
    public ResponseBodyVO<String> delete(@RequestParam("key") String key) {
        //4 根据 key 删除
        redisTemplate.delete(key);
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS);
    }

}